#!/usr/bin/env python
import pandas as pd
import numpy as np
from tooldistillator.interfaces import (
    ToolDistillatorResultIterator,
)

required_metadata = {
    "analysis_software_version": "abricate version",
    "reference_database_version": "DB version",
    "hid": "historic ID for abricate file from galaxy",
}


class AbricateIterator(ToolDistillatorResultIterator):
    """
    Abricate tool parser

    | Extract all results from abricate report.tsv file

    | Args:
    |     ToolDistillatorResultIterator: class to the parser
    """
    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "abricate"
        super().__init__(source, metadata)
        self.tooldistillator_results["tool_has_database"] = True
        self.parse()

    def parse(self):
        """
        Extract header of file and related results
        """
        if self.stream:
            reader = pd.read_table(self.stream, header=0, sep="\t")
            reader.columns = reader.columns.str.replace("#", "", regex=True)
            reader.columns = reader.columns.str.lower()
            reader = reader.drop(["coverage_map"], axis=1)
            extract_length = reader.coverage.str.split("/", expand=True)
            if len(extract_length) > 0:
                reader["length"] = extract_length[1]
            reader = reader.replace({np.nan: None})
            reader = reader.to_dict(orient="records")
            self.tooldistillator_results["results"][0]["content"] = reader
