#!/usr/bin/env python
import pandas as pd
from tooldistillator.interfaces import (
    ToolDistillatorResultIterator,
)

required_metadata = {
    "hid": "kraken report hid",
    "analysis_software_version": "kraken2 version",
    "reference_database_version": "kraken2 DB version",
    "seq_classification_file_path": (
        "file containing the classification of each reads"
    ),
    "seq_classification_file_hid": (
        "historic ID for read classification file from Galaxy"
    ),
}


class Kraken2Iterator(ToolDistillatorResultIterator):
    """
    Kraken2 tool parser

    | Filter results from kraken2 taxonomy report.
    | Could also give path information for:
    |     Read taxa assignation

    | Args:
    |     ToolDistillatorResultIterator: abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "kraken2"
        self.metadata = metadata
        self.colnames = [
            "fragment_coverage",
            "fragment_number",
            "assigned_fragment_number",
            "rank_code",
            "ncbi_taxonomic_id",
            "scientific_name",
        ]
        super().__init__(source, self.metadata)
        self.tooldistillator_results["tool_has_database"] = True
        self.parse()

    def parse(self):
        """
        | Extract taxonomy information
        | Extract read assignation file path
        """
        # skip any manually specified fields for later
        if self.stream:
            reader = pd.read_table(self.stream, header=None, sep="\t")
            reader.columns = self.colnames
            reader = reader.replace("^[ \t]+", "", regex=True)
            reader = reader.replace(" ", "_", regex=True)
            reader = reader.to_dict(orient="records")
            self.tooldistillator_results["results"][0]["content"] = reader
        self.extract_metadata_information(self.metadata)
