#!/usr/bin/env python

from Bio import SeqIO
from tooldistillator.interfaces import (
    ToolDistillatorResultIterator,
)

required_metadata = {
    "hid": "Historic ID to polypolish contigs file from Galaxy",
    "analysis_software_version": "polypolish version number",
    "reference_database_version": "DB version",
}


class PolypolishIterator(ToolDistillatorResultIterator):
    """
    Polypolish tool parser

    | Filter results from contig fasta file

    | Args:
    |     ToolDistillatorResultIterator: abstract class to the parser
    """

    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "polypolish"
        self.metadata = metadata
        super().__init__(source, metadata)
        self.tooldistillator_results["tool_has_database"] = False
        self.parse()

    def parse(self):
        """
        Assembly polypolish parser

        | Read contig assembly file to extract informations and sequences
        """
        if self.stream:
            parsed_fa = self.__get_fasta_infos__()
            self.tooldistillator_results["results"][0]["content"] = parsed_fa
        self.extract_metadata_information(self.metadata)

    def __get_fasta_infos__(self):
        """
        Extract fasta informations

        | Extract name, sequences, positions
        | and IS information

        | Returns:
        |     dict: sequence informations
        """
        fasta_sequences = SeqIO.parse(self.stream, format="fasta")
        parsed_fasta_sequence = []
        for seqname in fasta_sequences:
            seq_results = {}
            seq_results["name"] = seqname.id
            seq_results["length"] = len(seqname.seq)
            seq_results["sequence"] = seqname.seq.__str__()
            parsed_fasta_sequence.append(seq_results)
        return parsed_fasta_sequence
